@@ -30,9 +30,8 @@
 #include "gdal_pam.h"
 #include "zlib.h"
 
-/* g++ -fPIC -g -Wall frmts/ozi/ozidataset.cpp -shared -o gdal_OZI.so -Iport -Igcore -Iogr -L. -lgdal  */
-
-CPL_CVSID("$Id$")
+/* g++ -fPIC -g -Wall frmts/ozi/ozidataset.cpp -shared -o gdal_OZI.so -Iport
+ * -Igcore -Iogr -L. -lgdal  */
 
 /************************************************************************/
 /* ==================================================================== */
@@ -42,25 +41,25 @@ CPL_CVSID("$Id$")
 
 class OZIRasterBand;
 
-class OZIDataset final: public GDALPamDataset
+class OZIDataset final : public GDALPamDataset
 {
     friend class OZIRasterBand;
 
-    VSILFILE* fp;
-    int       nZoomLevelCount;
-    int*      panZoomLevelOffsets;
-    OZIRasterBand** papoOvrBands;
+    VSILFILE *fp;
+    int nZoomLevelCount;
+    int *panZoomLevelOffsets;
+    OZIRasterBand **papoOvrBands;
     vsi_l_offset nFileSize;
 
     int bOzi3;
     GByte nKeyInit;
 
   public:
-                 OZIDataset();
-    virtual     ~OZIDataset();
+    OZIDataset();
+    virtual ~OZIDataset();
 
-    static GDALDataset *Open( GDALOpenInfo * );
-    static int          Identify( GDALOpenInfo * );
+    static GDALDataset *Open(GDALOpenInfo *);
+    static int Identify(GDALOpenInfo *);
 };
 
 /************************************************************************/
@@ -69,53 +68,47 @@ class OZIDataset final: public GDALPamDataset
 /* ==================================================================== */
 /************************************************************************/
 
-class OZIRasterBand final: public GDALPamRasterBand
+class OZIRasterBand final : public GDALPamRasterBand
 {
     friend class OZIDataset;
 
     int nXBlocks;
     int nZoomLevel;
-    GDALColorTable* poColorTable;
-    GByte* pabyTranslationTable;
+    GDALColorTable *poColorTable;
+    GByte *pabyTranslationTable;
 
   public:
+    OZIRasterBand(OZIDataset *, int nZoomLevel, int nRasterXSize,
+                  int nRasterYSize, int nXBlocks, GDALColorTable *poColorTable);
+    virtual ~OZIRasterBand();
 
-                OZIRasterBand( OZIDataset *, int nZoomLevel,
-                               int nRasterXSize, int nRasterYSize,
-                               int nXBlocks,
-                               GDALColorTable* poColorTable);
-    virtual    ~OZIRasterBand();
-
-    virtual CPLErr IReadBlock( int, int, void * ) override;
+    virtual CPLErr IReadBlock(int, int, void *) override;
     virtual GDALColorInterp GetColorInterpretation() override;
     virtual GDALColorTable *GetColorTable() override;
 
-    virtual int         GetOverviewCount() override;
-    virtual GDALRasterBand* GetOverview(int nLevel) override;
+    virtual int GetOverviewCount() override;
+    virtual GDALRasterBand *GetOverview(int nLevel) override;
 };
 
 /************************************************************************/
 /*                             I/O functions                            */
 /************************************************************************/
 
-constexpr GByte abyKey[] =
-{
-    0x2D, 0x4A, 0x43, 0xF1, 0x27, 0x9B, 0x69, 0x4F,
-    0x36, 0x52, 0x87, 0xEC, 0x5F, 0x42, 0x53, 0x22,
-    0x9E, 0x8B, 0x2D, 0x83, 0x3D, 0xD2, 0x84, 0xBA,
-    0xD8, 0x5B
-};
+constexpr GByte abyKey[] = {0x2D, 0x4A, 0x43, 0xF1, 0x27, 0x9B, 0x69,
+                            0x4F, 0x36, 0x52, 0x87, 0xEC, 0x5F, 0x42,
+                            0x53, 0x22, 0x9E, 0x8B, 0x2D, 0x83, 0x3D,
+                            0xD2, 0x84, 0xBA, 0xD8, 0x5B};
 
 static void OZIDecrypt(void *pabyVal, int n, GByte nKeyInit)
 {
-    for(int i = 0; i < n; i++)
+    for (int i = 0; i < n; i++)
     {
-        reinterpret_cast<GByte*>( pabyVal )[i]
-            ^= abyKey[i % sizeof(abyKey)] + nKeyInit;
+        reinterpret_cast<GByte *>(pabyVal)[i] ^=
+            abyKey[i % sizeof(abyKey)] + nKeyInit;
     }
 }
 
-static int ReadInt(GByte**pptr)
+static int ReadInt(GByte **pptr)
 {
     int nVal;
     memcpy(&nVal, *pptr, 4);
@@ -124,7 +117,7 @@ static int ReadInt(GByte**pptr)
     return nVal;
 }
 
-static short ReadShort(GByte**pptr)
+static short ReadShort(GByte **pptr)
 {
     short nVal;
     memcpy(&nVal, *pptr, 2);
@@ -133,7 +126,7 @@ static short ReadShort(GByte**pptr)
     return nVal;
 }
 
-static int ReadInt( VSILFILE* fp, int bOzi3 = FALSE, int nKeyInit = 0 )
+static int ReadInt(VSILFILE *fp, int bOzi3 = FALSE, int nKeyInit = 0)
 {
     int nVal;
     VSIFReadL(&nVal, 1, 4, fp);
@@ -141,14 +134,14 @@ static int ReadInt( VSILFILE* fp, int bOzi3 = FALSE, int nKeyInit = 0 )
     {
         GByte abyVal[4];
         memcpy(&abyVal[0], &nVal, 4);
-        OZIDecrypt(&abyVal[0], 4, static_cast<GByte>( nKeyInit ) );
+        OZIDecrypt(&abyVal[0], 4, static_cast<GByte>(nKeyInit));
         memcpy(&nVal, &abyVal[0], 4);
     }
     CPL_LSBPTR32(&nVal);
     return nVal;
 }
 
-static short ReadShort( VSILFILE* fp, int bOzi3 = FALSE, int nKeyInit = 0 )
+static short ReadShort(VSILFILE *fp, int bOzi3 = FALSE, int nKeyInit = 0)
 {
     short nVal;
     VSIFReadL(&nVal, 1, 2, fp);
@@ -156,7 +149,7 @@ static short ReadShort( VSILFILE* fp, int bOzi3 = FALSE, int nKeyInit = 0 )
     {
         GByte abyVal[2];
         memcpy(&abyVal[0], &nVal, 2);
-        OZIDecrypt(&abyVal[0], 2, static_cast<GByte>( nKeyInit ) );
+        OZIDecrypt(&abyVal[0], 2, static_cast<GByte>(nKeyInit));
         memcpy(&nVal, &abyVal[0], 2);
     }
     CPL_LSBPTR16(&nVal);
@@ -167,14 +160,11 @@ static short ReadShort( VSILFILE* fp, int bOzi3 = FALSE, int nKeyInit = 0 )
 /*                         OZIRasterBand()                             */
 /************************************************************************/
 
-OZIRasterBand::OZIRasterBand( OZIDataset *poDSIn, int nZoomLevelIn,
-                              int nRasterXSizeIn, int nRasterYSizeIn,
-                              int nXBlocksIn,
-                              GDALColorTable* poColorTableIn ) :
-    nXBlocks(nXBlocksIn),
-    nZoomLevel(nZoomLevelIn),
-    poColorTable(poColorTableIn),
-    pabyTranslationTable(nullptr)
+OZIRasterBand::OZIRasterBand(OZIDataset *poDSIn, int nZoomLevelIn,
+                             int nRasterXSizeIn, int nRasterYSizeIn,
+                             int nXBlocksIn, GDALColorTable *poColorTableIn)
+    : nXBlocks(nXBlocksIn), nZoomLevel(nZoomLevelIn),
+      poColorTable(poColorTableIn), pabyTranslationTable(nullptr)
 {
     poDS = poDSIn;
     nBand = 1;
@@ -211,7 +201,7 @@ GDALColorInterp OZIRasterBand::GetColorInterpretation()
 /*                            GetColorTable()                           */
 /************************************************************************/
 
-GDALColorTable* OZIRasterBand::GetColorTable()
+GDALColorTable *OZIRasterBand::GetColorTable()
 {
     return poColorTable;
 }
@@ -220,44 +210,44 @@ GDALColorTable* OZIRasterBand::GetColorTable()
 /*                             IReadBlock()                             */
 /************************************************************************/
 
-CPLErr OZIRasterBand::IReadBlock( int nBlockXOff, int nBlockYOff,
-                                  void * pImage )
+CPLErr OZIRasterBand::IReadBlock(int nBlockXOff, int nBlockYOff, void *pImage)
 
 {
-    OZIDataset *poGDS = reinterpret_cast<OZIDataset *>( poDS );
+    OZIDataset *poGDS = reinterpret_cast<OZIDataset *>(poDS);
 
     const int nBlock = nBlockYOff * nXBlocks + nBlockXOff;
 
-    VSIFSeekL(poGDS->fp, poGDS->panZoomLevelOffsets[nZoomLevel] +
-                         12 + 1024 + 4 * nBlock, SEEK_SET);
+    VSIFSeekL(poGDS->fp,
+              poGDS->panZoomLevelOffsets[nZoomLevel] + 12 + 1024 + 4 * nBlock,
+              SEEK_SET);
     const int nPointer = ReadInt(poGDS->fp, poGDS->bOzi3, poGDS->nKeyInit);
-    if (nPointer < 0  || (vsi_l_offset)nPointer >= poGDS->nFileSize)
+    if (nPointer < 0 || (vsi_l_offset)nPointer >= poGDS->nFileSize)
     {
         CPLError(CE_Failure, CPLE_AppDefined,
-                 "Invalid offset for block (%d, %d) : %d",
-                 nBlockXOff, nBlockYOff, nPointer);
+                 "Invalid offset for block (%d, %d) : %d", nBlockXOff,
+                 nBlockYOff, nPointer);
         return CE_Failure;
     }
     int nNextPointer = ReadInt(poGDS->fp, poGDS->bOzi3, poGDS->nKeyInit);
-    if (nNextPointer <= nPointer + 16  ||
+    if (nNextPointer <= nPointer + 16 ||
         (vsi_l_offset)nNextPointer >= poGDS->nFileSize ||
         nNextPointer - nPointer > 10 * 64 * 64)
     {
         CPLError(CE_Failure, CPLE_AppDefined,
-                 "Invalid next offset for block (%d, %d) : %d",
-                 nBlockXOff, nBlockYOff, nNextPointer);
+                 "Invalid next offset for block (%d, %d) : %d", nBlockXOff,
+                 nBlockYOff, nNextPointer);
         return CE_Failure;
     }
 
     VSIFSeekL(poGDS->fp, nPointer, SEEK_SET);
 
     const int nToRead = nNextPointer - nPointer;
-    GByte* pabyZlibBuffer = reinterpret_cast<GByte *>( CPLMalloc( nToRead ) );
+    GByte *pabyZlibBuffer = reinterpret_cast<GByte *>(CPLMalloc(nToRead));
     if (VSIFReadL(pabyZlibBuffer, nToRead, 1, poGDS->fp) != 1)
     {
         CPLError(CE_Failure, CPLE_AppDefined,
-                 "Not enough byte read for block (%d, %d)",
-                 nBlockXOff, nBlockYOff);
+                 "Not enough byte read for block (%d, %d)", nBlockXOff,
+                 nBlockYOff);
         CPLFree(pabyZlibBuffer);
         return CE_Failure;
     }
@@ -265,8 +255,7 @@ CPLErr OZIRasterBand::IReadBlock( int nBlockXOff, int nBlockYOff,
     if (poGDS->bOzi3)
         OZIDecrypt(pabyZlibBuffer, 16, poGDS->nKeyInit);
 
-    if (pabyZlibBuffer[0] != 0x78 ||
-        pabyZlibBuffer[1] != 0xDA)
+    if (pabyZlibBuffer[0] != 0x78 || pabyZlibBuffer[1] != 0xDA)
     {
         CPLError(CE_Failure, CPLE_AppDefined,
                  "Bad ZLIB signature for block (%d, %d) : 0x%02X 0x%02X",
@@ -275,31 +264,31 @@ CPLErr OZIRasterBand::IReadBlock( int nBlockXOff, int nBlockYOff,
         return CE_Failure;
     }
 
-    z_stream      stream;
+    z_stream stream;
     memset(&stream, 0, sizeof(stream));
-    stream.zalloc = (alloc_func)nullptr;
-    stream.zfree = (free_func)nullptr;
-    stream.opaque = (voidpf)nullptr;
+    stream.zalloc = (alloc_func) nullptr;
+    stream.zfree = (free_func) nullptr;
+    stream.opaque = (voidpf) nullptr;
     stream.next_in = pabyZlibBuffer + 2;
     stream.avail_in = nToRead - 2;
 
     int err = inflateInit2(&(stream), -MAX_WBITS);
 
-    for( int i = 0; i < 64 && err == Z_OK; i++ )
+    for (int i = 0; i < 64 && err == Z_OK; i++)
     {
-        stream.next_out = reinterpret_cast<Bytef *>( pImage ) + (63 - i) * 64;
+        stream.next_out = reinterpret_cast<Bytef *>(pImage) + (63 - i) * 64;
         stream.avail_out = 64;
-        err = inflate(& (stream), Z_NO_FLUSH);
+        err = inflate(&(stream), Z_NO_FLUSH);
         if (err != Z_OK && err != Z_STREAM_END)
             break;
 
         if (pabyTranslationTable)
         {
-            GByte* ptr = reinterpret_cast<GByte *>( pImage ) + (63 - i) * 64;
-            for( int j = 0; j < 64; j++ )
+            GByte *ptr = reinterpret_cast<GByte *>(pImage) + (63 - i) * 64;
+            for (int j = 0; j < 64; j++)
             {
                 *ptr = pabyTranslationTable[*ptr];
-                ptr ++;
+                ptr++;
             }
         }
     }
@@ -320,7 +309,7 @@ int OZIRasterBand::GetOverviewCount()
     if (nZoomLevel != 0)
         return 0;
 
-    OZIDataset *poGDS = reinterpret_cast<OZIDataset *>( poDS );
+    OZIDataset *poGDS = reinterpret_cast<OZIDataset *>(poDS);
     return poGDS->nZoomLevelCount - 1;
 }
 
@@ -328,12 +317,12 @@ int OZIRasterBand::GetOverviewCount()
 /*                            GetOverview()                             */
 /************************************************************************/
 
-GDALRasterBand* OZIRasterBand::GetOverview(int nLevel)
+GDALRasterBand *OZIRasterBand::GetOverview(int nLevel)
 {
     if (nZoomLevel != 0)
         return nullptr;
 
-    OZIDataset *poGDS = reinterpret_cast<OZIDataset *>( poDS );
+    OZIDataset *poGDS = reinterpret_cast<OZIDataset *>(poDS);
     if (nLevel < 0 || nLevel >= poGDS->nZoomLevelCount - 1)
         return nullptr;
 
@@ -344,15 +333,11 @@ GDALRasterBand* OZIRasterBand::GetOverview(int nLevel)
 /*                            ~OZIDataset()                            */
 /************************************************************************/
 
-OZIDataset::OZIDataset() :
-    fp(nullptr),
-    nZoomLevelCount(0),
-    panZoomLevelOffsets(nullptr),
-    papoOvrBands(nullptr),
-    nFileSize(0),
-    bOzi3(FALSE),
-    nKeyInit(0)
-{}
+OZIDataset::OZIDataset()
+    : fp(nullptr), nZoomLevelCount(0), panZoomLevelOffsets(nullptr),
+      papoOvrBands(nullptr), nFileSize(0), bOzi3(FALSE), nKeyInit(0)
+{
+}
 
 /************************************************************************/
 /*                            ~OZIDataset()                            */
@@ -362,10 +347,10 @@ OZIDataset::~OZIDataset()
 {
     if (fp)
         VSIFCloseL(fp);
-    if (papoOvrBands != nullptr )
+    if (papoOvrBands != nullptr)
     {
         /* start at 1: do not destroy the base band ! */
-        for(int i=1;i<nZoomLevelCount;i++)
+        for (int i = 1; i < nZoomLevelCount; i++)
             delete papoOvrBands[i];
         CPLFree(papoOvrBands);
     }
@@ -376,13 +361,12 @@ OZIDataset::~OZIDataset()
 /*                             Identify()                               */
 /************************************************************************/
 
-int OZIDataset::Identify( GDALOpenInfo * poOpenInfo )
+int OZIDataset::Identify(GDALOpenInfo *poOpenInfo)
 {
     if (poOpenInfo->nHeaderBytes < 14)
         return FALSE;
 
-    if (poOpenInfo->pabyHeader[0] == 0x80 &&
-        poOpenInfo->pabyHeader[1] == 0x77)
+    if (poOpenInfo->pabyHeader[0] == 0x80 && poOpenInfo->pabyHeader[1] == 0x77)
         return TRUE;
 
     return poOpenInfo->pabyHeader[0] == 0x78 &&
@@ -401,7 +385,7 @@ int OZIDataset::Identify( GDALOpenInfo * poOpenInfo )
 /*                                Open()                                */
 /************************************************************************/
 
-GDALDataset *OZIDataset::Open( GDALOpenInfo * poOpenInfo )
+GDALDataset *OZIDataset::Open(GDALOpenInfo *poOpenInfo)
 
 {
     if (!Identify(poOpenInfo))
@@ -410,15 +394,14 @@ GDALDataset *OZIDataset::Open( GDALOpenInfo * poOpenInfo )
     GByte abyHeader[14];
     memcpy(abyHeader, poOpenInfo->pabyHeader, 14);
 
-    int bOzi3 = (abyHeader[0] == 0x80 &&
-                 abyHeader[1] == 0x77);
+    int bOzi3 = (abyHeader[0] == 0x80 && abyHeader[1] == 0x77);
 
     const CPLString osImgFilename = poOpenInfo->pszFilename;
-    VSILFILE* fp = VSIFOpenL(osImgFilename.c_str(), "rb");
+    VSILFILE *fp = VSIFOpenL(osImgFilename.c_str(), "rb");
     if (fp == nullptr)
         return nullptr;
 
-    OZIDataset* poDS = new OZIDataset();
+    OZIDataset *poDS = new OZIDataset();
     poDS->fp = fp;
 
     GByte nKeyInit = 0;
@@ -428,7 +411,7 @@ GDALDataset *OZIDataset::Open( GDALOpenInfo * poOpenInfo )
 
         GByte nRandomNumber = 0;
         VSIFReadL(&nRandomNumber, 1, 1, fp);
-        //printf("nRandomNumber = %d\n", nRandomNumber);
+        // printf("nRandomNumber = %d\n", nRandomNumber);
         if (nRandomNumber < 0x94)
         {
             delete poDS;
@@ -440,14 +423,10 @@ GDALDataset *OZIDataset::Open( GDALOpenInfo * poOpenInfo )
         VSIFSeekL(fp, 0, SEEK_SET);
         VSIFReadL(abyHeader, 1, 14, fp);
         OZIDecrypt(abyHeader, 14, nKeyInit);
-        if (!(abyHeader[6] == 0x40 &&
-           abyHeader[7] == 0x00 &&
-           abyHeader[8] == 0x01 &&
-           abyHeader[9] == 0x00 &&
-           abyHeader[10] == 0x36 &&
-           abyHeader[11] == 0x04 &&
-           abyHeader[12] == 0x00 &&
-           abyHeader[13] == 0x00))
+        if (!(abyHeader[6] == 0x40 && abyHeader[7] == 0x00 &&
+              abyHeader[8] == 0x01 && abyHeader[9] == 0x00 &&
+              abyHeader[10] == 0x36 && abyHeader[11] == 0x04 &&
+              abyHeader[12] == 0x00 && abyHeader[13] == 0x00))
         {
             delete poDS;
             return nullptr;
@@ -472,10 +451,10 @@ GDALDataset *OZIDataset::Open( GDALOpenInfo * poOpenInfo )
     /* and the nKeyInit, but I'm too lazy to add switch/cases that might */
     /* be not exhaustive, so let's try the 'brute force' attack !!! */
     /* It is much so funny to be able to run one in a few microseconds :-) */
-    for( int i = 0; i < 256; i++ )
+    for (int i = 0; i < 256; i++)
     {
-        nKeyInit = static_cast<GByte>( i );
-        GByte* pabyHeader2 = abyHeader2;
+        nKeyInit = static_cast<GByte>(i);
+        GByte *pabyHeader2 = abyHeader2;
         if (bOzi3)
             OZIDecrypt(abyHeader2, 40, nKeyInit);
 
@@ -483,8 +462,8 @@ GDALDataset *OZIDataset::Open( GDALOpenInfo * poOpenInfo )
         poDS->nRasterXSize = ReadInt(&pabyHeader2);
         poDS->nRasterYSize = ReadInt(&pabyHeader2);
         const int nDepth = ReadShort(&pabyHeader2); /* should be 1 */
-        const int nBPP = ReadShort(&pabyHeader2); /* should be 8 */
-        ReadInt(&pabyHeader2); /* reserved */
+        const int nBPP = ReadShort(&pabyHeader2);   /* should be 8 */
+        ReadInt(&pabyHeader2);                      /* reserved */
         ReadInt(&pabyHeader2); /* pixel number (height * width) : unused */
         ReadInt(&pabyHeader2); /* reserved */
         ReadInt(&pabyHeader2); /* reserved */
@@ -497,12 +476,12 @@ GDALDataset *OZIDataset::Open( GDALOpenInfo * poOpenInfo )
             {
                 if (nKeyInit != 255)
                 {
-                    memcpy(abyHeader2, abyHeader2_Backup,40);
+                    memcpy(abyHeader2, abyHeader2_Backup, 40);
                     continue;
                 }
                 else
                 {
-                  CPLDebug( "OZI", "Cannot decipher 2nd header. Sorry..." );
+                    CPLDebug("OZI", "Cannot decipher 2nd header. Sorry...");
                     delete poDS;
                     return nullptr;
                 }
@@ -510,7 +489,7 @@ GDALDataset *OZIDataset::Open( GDALOpenInfo * poOpenInfo )
             else
             {
                 CPLDebug("OZI", "nHeaderSize = %d, nDepth = %d, nBPP = %d",
-                        nHeaderSize, nDepth, nBPP);
+                         nHeaderSize, nDepth, nBPP);
                 delete poDS;
                 return nullptr;
             }
@@ -568,8 +547,7 @@ GDALDataset *OZIDataset::Open( GDALOpenInfo * poOpenInfo )
     if (nZoomLevelTableOffset < 0 ||
         (vsi_l_offset)nZoomLevelTableOffset >= nFileSize)
     {
-        CPLDebug("OZI", "nZoomLevelTableOffset = %d",
-                 nZoomLevelTableOffset);
+        CPLDebug("OZI", "nZoomLevelTableOffset = %d", nZoomLevelTableOffset);
         delete poDS;
         return nullptr;
     }
@@ -577,27 +555,25 @@ GDALDataset *OZIDataset::Open( GDALOpenInfo * poOpenInfo )
     VSIFSeekL(fp, nZoomLevelTableOffset, SEEK_SET);
 
     poDS->panZoomLevelOffsets =
-        reinterpret_cast<int *>(
-            CPLMalloc( sizeof(int) * poDS->nZoomLevelCount ) );
+        reinterpret_cast<int *>(CPLMalloc(sizeof(int) * poDS->nZoomLevelCount));
 
-    for( int i = 0; i < poDS->nZoomLevelCount; i++ )
+    for (int i = 0; i < poDS->nZoomLevelCount; i++)
     {
         poDS->panZoomLevelOffsets[i] = ReadInt(fp, bOzi3, nKeyInit);
         if (poDS->panZoomLevelOffsets[i] < 0 ||
             (vsi_l_offset)poDS->panZoomLevelOffsets[i] >= nFileSize)
         {
-            CPLDebug("OZI", "panZoomLevelOffsets[%d] = %d",
-                     i, poDS->panZoomLevelOffsets[i]);
+            CPLDebug("OZI", "panZoomLevelOffsets[%d] = %d", i,
+                     poDS->panZoomLevelOffsets[i]);
             delete poDS;
             return nullptr;
         }
     }
 
-    poDS->papoOvrBands =
-        reinterpret_cast<OZIRasterBand **>(
-            CPLCalloc( sizeof( OZIRasterBand * ), poDS->nZoomLevelCount ) );
+    poDS->papoOvrBands = reinterpret_cast<OZIRasterBand **>(
+        CPLCalloc(sizeof(OZIRasterBand *), poDS->nZoomLevelCount));
 
-    for( int i = 0; i < poDS->nZoomLevelCount; i++ )
+    for (int i = 0; i < poDS->nZoomLevelCount; i++)
     {
         VSIFSeekL(fp, poDS->panZoomLevelOffsets[i], SEEK_SET);
         const int nW = ReadInt(fp, bOzi3, nKeyInit);
@@ -606,7 +582,8 @@ GDALDataset *OZIDataset::Open( GDALOpenInfo * poOpenInfo )
         const short nTileY = ReadShort(fp, bOzi3, nKeyInit);
         if (i == 0 && (nW != poDS->nRasterXSize || nH != poDS->nRasterYSize))
         {
-            CPLDebug("OZI", "zoom[%d] inconsistent dimensions for zoom level 0 "
+            CPLDebug("OZI",
+                     "zoom[%d] inconsistent dimensions for zoom level 0 "
                      ": nW=%d, nH=%d, nTileX=%d, nTileY=%d, nRasterXSize=%d, "
                      "nRasterYSize=%d",
                      i, nW, nH, nTileX, nTileY, poDS->nRasterXSize,
@@ -614,62 +591,71 @@ GDALDataset *OZIDataset::Open( GDALOpenInfo * poOpenInfo )
             delete poDS;
             return nullptr;
         }
-        /* Note (#3895): some files such as world.ozf2 provided with OziExplorer */
-        /* expose nTileY=33, but have nH=2048, so only require 32 tiles in vertical dimension. */
-        /* So there's apparently one extra and useless tile that will be ignored */
+        /* Note (#3895): some files such as world.ozf2 provided with OziExplorer
+         */
+        /* expose nTileY=33, but have nH=2048, so only require 32 tiles in
+         * vertical dimension. */
+        /* So there's apparently one extra and useless tile that will be ignored
+         */
         /* without causing apparent issues */
-        /* Some other files have more tile in horizontal direction than needed, so let's */
-        /* accept that. But in that case we really need to keep the nTileX value for IReadBlock() */
+        /* Some other files have more tile in horizontal direction than needed,
+         * so let's */
+        /* accept that. But in that case we really need to keep the nTileX value
+         * for IReadBlock() */
         /* to work properly */
         if ((nW + 63) / 64 > nTileX || (nH + 63) / 64 > nTileY)
         {
-            CPLDebug("OZI", "zoom[%d] unexpected number of tiles : nW=%d, "
+            CPLDebug("OZI",
+                     "zoom[%d] unexpected number of tiles : nW=%d, "
                      "nH=%d, nTileX=%d, nTileY=%d",
                      i, nW, nH, nTileX, nTileY);
             delete poDS;
             return nullptr;
         }
 
-        GDALColorTable* poColorTable = new GDALColorTable();
-        GByte abyColorTable[256*4];
+        GDALColorTable *poColorTable = new GDALColorTable();
+        GByte abyColorTable[256 * 4];
         VSIFReadL(abyColorTable, 1, 1024, fp);
         if (bOzi3)
             OZIDecrypt(abyColorTable, 1024, nKeyInit);
-        for( int j = 0; j < 256; j++ )
+        for (int j = 0; j < 256; j++)
         {
             GDALColorEntry sEntry;
-            sEntry.c1 = abyColorTable[4*j + 2];
-            sEntry.c2 = abyColorTable[4*j + 1];
-            sEntry.c3 = abyColorTable[4*j + 0];
+            sEntry.c1 = abyColorTable[4 * j + 2];
+            sEntry.c2 = abyColorTable[4 * j + 1];
+            sEntry.c3 = abyColorTable[4 * j + 0];
             sEntry.c4 = 255;
             poColorTable->SetColorEntry(j, &sEntry);
         }
 
-        poDS->papoOvrBands[i] = new OZIRasterBand(poDS, i, nW, nH, nTileX, poColorTable);
+        poDS->papoOvrBands[i] =
+            new OZIRasterBand(poDS, i, nW, nH, nTileX, poColorTable);
 
         if (i > 0)
         {
-            GByte* pabyTranslationTable =
-                poDS->papoOvrBands[i]->GetIndexColorTranslationTo(poDS->papoOvrBands[0], nullptr, nullptr);
+            GByte *pabyTranslationTable =
+                poDS->papoOvrBands[i]->GetIndexColorTranslationTo(
+                    poDS->papoOvrBands[0], nullptr, nullptr);
 
             delete poDS->papoOvrBands[i]->poColorTable;
-            poDS->papoOvrBands[i]->poColorTable = poDS->papoOvrBands[0]->poColorTable->Clone();
+            poDS->papoOvrBands[i]->poColorTable =
+                poDS->papoOvrBands[0]->poColorTable->Clone();
             poDS->papoOvrBands[i]->pabyTranslationTable = pabyTranslationTable;
         }
     }
 
     poDS->SetBand(1, poDS->papoOvrBands[0]);
 
-/* -------------------------------------------------------------------- */
-/*      Initialize any PAM information.                                 */
-/* -------------------------------------------------------------------- */
-    poDS->SetDescription( poOpenInfo->pszFilename );
+    /* -------------------------------------------------------------------- */
+    /*      Initialize any PAM information.                                 */
+    /* -------------------------------------------------------------------- */
+    poDS->SetDescription(poOpenInfo->pszFilename);
     poDS->TryLoadXML();
 
-/* -------------------------------------------------------------------- */
-/*      Support overviews.                                              */
-/* -------------------------------------------------------------------- */
-    poDS->oOvManager.Initialize( poDS, poOpenInfo->pszFilename );
+    /* -------------------------------------------------------------------- */
+    /*      Support overviews.                                              */
+    /* -------------------------------------------------------------------- */
+    poDS->oOvManager.Initialize(poDS, poOpenInfo->pszFilename);
     return poDS;
 }
 
@@ -680,22 +666,22 @@ GDALDataset *OZIDataset::Open( GDALOpenInfo * poOpenInfo )
 void GDALRegister_OZI()
 
 {
-    if( !GDAL_CHECK_VERSION( "OZI driver" ) )
+    if (!GDAL_CHECK_VERSION("OZI driver"))
         return;
 
-    if( GDALGetDriverByName( "OZI" ) != nullptr )
+    if (GDALGetDriverByName("OZI") != nullptr)
         return;
 
     GDALDriver *poDriver = new GDALDriver();
 
-    poDriver->SetDescription( "OZI" );
-    poDriver->SetMetadataItem( GDAL_DCAP_RASTER, "YES" );
-    poDriver->SetMetadataItem( GDAL_DMD_LONGNAME, "OziExplorer Image File" );
-    poDriver->SetMetadataItem( GDAL_DMD_HELPTOPIC, "drivers/raster/ozi.html" );
-    poDriver->SetMetadataItem( GDAL_DCAP_VIRTUALIO, "YES" );
+    poDriver->SetDescription("OZI");
+    poDriver->SetMetadataItem(GDAL_DCAP_RASTER, "YES");
+    poDriver->SetMetadataItem(GDAL_DMD_LONGNAME, "OziExplorer Image File");
+    poDriver->SetMetadataItem(GDAL_DMD_HELPTOPIC, "drivers/raster/ozi.html");
+    poDriver->SetMetadataItem(GDAL_DCAP_VIRTUALIO, "YES");
 
     poDriver->pfnOpen = OZIDataset::Open;
     poDriver->pfnIdentify = OZIDataset::Identify;
 
-    GetGDALDriverManager()->RegisterDriver( poDriver );
+    GetGDALDriverManager()->RegisterDriver(poDriver);
 }
